import "reflect-metadata"; // Required for TypeORM
import express from "express";
import MercuryDataSource from "./db/index.js";
import log from "./log.js";
import { Blog } from "./db/entities/blog.js";
import { PORT } from "./config.js";

export default async function start() {
  log.info("Initializing database");
  await MercuryDataSource.initialize();

  const pendingMigrations = await MercuryDataSource.showMigrations();
  if (pendingMigrations) {
    log.error(
      "There are pending migrations, please run these with `pnpm migrate`."
    );
    return;
  }

  log.debug("Setting up routes")
  const app = express();

  app.get("/", async (_, res) => {
    const blogRepository = MercuryDataSource.getRepository(Blog);

    const resp = await blogRepository.find();

    return res.json(resp)
  })

  log.info("Listening on port %d", PORT)
  app.listen(PORT);
}
